summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorCaolán McNamara <caolanm@redhat.com>2014-07-21 10:40:45 +0100
committerCaolán McNamara <caolanm@redhat.com>2014-07-21 13:59:34 +0100
commit8923103eeedc79ee8e4384ea4a1df57d76a0d5d4 (patch)
treee074dd6049e24beeee93c36258b615557f443f6e
parentd4758e6f699259e865426fd761c58009d3eca7d1 (diff)
coverity#706376 Uncaught exception
Change-Id: Ic18823fd60826c144058df32c27ab25d58664e30
-rw-r--r--connectivity/source/commontools/BlobHelper.cxx6
-rw-r--r--connectivity/source/commontools/dbexception.cxx15
-rw-r--r--connectivity/source/drivers/ado/ACallableStatement.cxx14
-rw-r--r--connectivity/source/drivers/ado/AConnection.cxx2
-rw-r--r--connectivity/source/drivers/ado/ADatabaseMetaData.cxx2
-rw-r--r--connectivity/source/drivers/ado/ADatabaseMetaDataResultSet.cxx16
-rw-r--r--connectivity/source/drivers/ado/APreparedStatement.cxx10
-rw-r--r--connectivity/source/drivers/ado/AResultSet.cxx14
-rw-r--r--connectivity/source/drivers/ado/AStatement.cxx4
-rw-r--r--connectivity/source/drivers/calc/CConnection.cxx2
-rw-r--r--connectivity/source/drivers/calc/CResultSet.cxx2
-rw-r--r--connectivity/source/drivers/dbase/DConnection.cxx2
-rw-r--r--connectivity/source/drivers/dbase/DResultSet.cxx2
-rw-r--r--connectivity/source/drivers/evoab2/NConnection.cxx14
-rw-r--r--connectivity/source/drivers/evoab2/NDatabaseMetaData.cxx2
-rw-r--r--connectivity/source/drivers/evoab2/NPreparedStatement.cxx2
-rw-r--r--connectivity/source/drivers/evoab2/NStatement.cxx2
-rw-r--r--connectivity/source/drivers/file/FConnection.cxx6
-rw-r--r--connectivity/source/drivers/file/FPreparedStatement.cxx10
-rw-r--r--connectivity/source/drivers/file/FResultSet.cxx2
-rw-r--r--connectivity/source/drivers/firebird/Blob.cxx4
-rw-r--r--connectivity/source/drivers/firebird/Connection.cxx4
-rw-r--r--connectivity/source/drivers/flat/EConnection.cxx2
-rw-r--r--connectivity/source/drivers/hsqldb/HDriver.cxx2
-rw-r--r--connectivity/source/drivers/jdbc/Blob.cxx2
-rw-r--r--connectivity/source/drivers/jdbc/Clob.cxx2
-rw-r--r--connectivity/source/drivers/jdbc/JConnection.cxx2
-rw-r--r--connectivity/source/drivers/jdbc/PreparedStatement.cxx8
-rw-r--r--connectivity/source/drivers/jdbc/ResultSet.cxx4
-rw-r--r--connectivity/source/drivers/jdbc/tools.cxx2
-rw-r--r--connectivity/source/drivers/mork/MConnection.cxx12
-rw-r--r--connectivity/source/drivers/mork/MPreparedStatement.cxx38
-rw-r--r--connectivity/source/drivers/mork/MResultSet.cxx4
-rw-r--r--connectivity/source/drivers/mork/MStatement.cxx2
-rw-r--r--connectivity/source/drivers/mozab/MConnection.cxx12
-rw-r--r--connectivity/source/drivers/mozab/MPreparedStatement.cxx38
-rw-r--r--connectivity/source/drivers/mozab/MResultSet.cxx4
-rw-r--r--connectivity/source/drivers/mozab/MStatement.cxx2
-rw-r--r--connectivity/source/drivers/odbc/OConnection.cxx4
-rw-r--r--connectivity/source/sdbcx/VGroup.cxx6
-rw-r--r--connectivity/source/sdbcx/VTable.cxx4
-rw-r--r--connectivity/source/sdbcx/VUser.cxx10
-rw-r--r--dbaccess/source/core/api/RowSet.cxx8
-rw-r--r--dbaccess/source/core/api/RowSetBase.cxx4
-rw-r--r--include/connectivity/dbexception.hxx18
45 files changed, 176 insertions, 151 deletions
diff --git a/connectivity/source/commontools/dbexception.cxx b/connectivity/source/commontools/dbexception.cxx
index b4990e8a93f7..d8b71ee4f25a 100644
--- a/connectivity/source/commontools/dbexception.cxx
+++ b/connectivity/source/commontools/dbexception.cxx
@@ -429,8 +429,7 @@ void throwGenericSQLException(const OUString& _rMsg, const Reference< XInterface
throw SQLException( _rMsg, _rxSource, getStandardSQLState( SQL_GENERAL_ERROR ), 0, _rNextException);
}
-
-void throwFeatureNotImplementedException( const OUString& _rFeatureName, const Reference< XInterface >& _rxContext, const Any* _pNextException )
+void throwFeatureNotImplementedSQLException( const OUString& _rFeatureName, const Reference< XInterface >& _rxContext, const Any* _pNextException )
throw (SQLException)
{
::connectivity::SharedResources aResources;
@@ -448,6 +447,18 @@ void throwFeatureNotImplementedException( const OUString& _rFeatureName, const R
);
}
+void throwFeatureNotImplementedRuntimeException(const OUString& _rFeatureName, const Reference< XInterface >& _rxContext)
+ throw (RuntimeException)
+{
+ ::connectivity::SharedResources aResources;
+ const OUString sError( aResources.getResourceStringWithSubstitution(
+ STR_UNSUPPORTED_FEATURE,
+ "$featurename$", _rFeatureName
+ ) );
+
+ throw RuntimeException(sError, _rxContext);
+}
+
void throwInvalidColumnException( const OUString& _rColumnName, const Reference< XInterface >& _rxContext)
throw (SQLException)
{
diff --git a/connectivity/source/drivers/ado/ACallableStatement.cxx b/connectivity/source/drivers/ado/ACallableStatement.cxx
index 0d8846f802f2..8e0c51081725 100644
--- a/connectivity/source/drivers/ado/ACallableStatement.cxx
+++ b/connectivity/source/drivers/ado/ACallableStatement.cxx
@@ -112,7 +112,7 @@ sal_Int64 SAL_CALL OCallableStatement::getLong( sal_Int32 columnIndex ) throw(SQ
Any SAL_CALL OCallableStatement::getObject( sal_Int32 /*columnIndex*/, const Reference< ::com::sun::star::container::XNameAccess >& /*typeMap*/ ) throw(SQLException, RuntimeException)
{
- ::dbtools::throwFeatureNotImplementedException( "XRow::getObject", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XRow::getObject", *this );
return Any();
}
@@ -172,40 +172,40 @@ void SAL_CALL OCallableStatement::registerNumericOutParameter( sal_Int32 paramet
Reference< ::com::sun::star::io::XInputStream > SAL_CALL OCallableStatement::getBinaryStream( sal_Int32 /*columnIndex*/ ) throw(SQLException, RuntimeException)
{
- ::dbtools::throwFeatureNotImplementedException( "XRow::getBinaryStream", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XRow::getBinaryStream", *this );
return NULL;
}
Reference< ::com::sun::star::io::XInputStream > SAL_CALL OCallableStatement::getCharacterStream( sal_Int32 /*columnIndex*/ ) throw(SQLException, RuntimeException)
{
- ::dbtools::throwFeatureNotImplementedException( "XRow::getCharacterStream", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XRow::getCharacterStream", *this );
return NULL;
}
Reference< XArray > SAL_CALL OCallableStatement::getArray( sal_Int32 /*columnIndex*/ ) throw(SQLException, RuntimeException)
{
- ::dbtools::throwFeatureNotImplementedException( "XRow::getArray", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XRow::getArray", *this );
return NULL;
}
Reference< XClob > SAL_CALL OCallableStatement::getClob( sal_Int32 /*columnIndex*/ ) throw(SQLException, RuntimeException)
{
- ::dbtools::throwFeatureNotImplementedException( "XRow::getClob", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XRow::getClob", *this );
return NULL;
}
Reference< XBlob > SAL_CALL OCallableStatement::getBlob( sal_Int32 /*columnIndex*/ ) throw(SQLException, RuntimeException)
{
- ::dbtools::throwFeatureNotImplementedException( "XRow::getBlob", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XRow::getBlob", *this );
return NULL;
}
Reference< XRef > SAL_CALL OCallableStatement::getRef( sal_Int32 /*columnIndex*/) throw(SQLException, RuntimeException)
{
- ::dbtools::throwFeatureNotImplementedException( "XRow::getRef", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XRow::getRef", *this );
return NULL;
}
diff --git a/connectivity/source/drivers/ado/AConnection.cxx b/connectivity/source/drivers/ado/AConnection.cxx
index 6dcb5628b828..79abed73a185 100644
--- a/connectivity/source/drivers/ado/AConnection.cxx
+++ b/connectivity/source/drivers/ado/AConnection.cxx
@@ -393,7 +393,7 @@ Reference< ::com::sun::star::container::XNameAccess > SAL_CALL OConnection::getT
void SAL_CALL OConnection::setTypeMap( const Reference< ::com::sun::star::container::XNameAccess >& /*typeMap*/ ) throw(SQLException, RuntimeException)
{
- ::dbtools::throwFeatureNotImplementedException( "XConnection::setTypeMap", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XConnection::setTypeMap", *this );
}
// XCloseable
diff --git a/connectivity/source/drivers/ado/ADatabaseMetaData.cxx b/connectivity/source/drivers/ado/ADatabaseMetaData.cxx
index 823dfa252c52..10349df86d62 100644
--- a/connectivity/source/drivers/ado/ADatabaseMetaData.cxx
+++ b/connectivity/source/drivers/ado/ADatabaseMetaData.cxx
@@ -1067,7 +1067,7 @@ sal_Bool SAL_CALL ODatabaseMetaData::supportsBatchUpdates( ) throw(SQLException
Reference< XResultSet > SAL_CALL ODatabaseMetaData::getUDTs( const Any& /*catalog*/, const OUString& /*schemaPattern*/, const OUString& /*typeNamePattern*/, const Sequence< sal_Int32 >& /*types*/ ) throw(SQLException, RuntimeException)
{
- ::dbtools::throwFeatureNotImplementedException( "XDatabaseMetaData::getUDTs", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XDatabaseMetaData::getUDTs", *this );
return Reference< XResultSet >();
}
diff --git a/connectivity/source/drivers/ado/ADatabaseMetaDataResultSet.cxx b/connectivity/source/drivers/ado/ADatabaseMetaDataResultSet.cxx
index 6627e8d93e1a..35a6b4359da5 100644
--- a/connectivity/source/drivers/ado/ADatabaseMetaDataResultSet.cxx
+++ b/connectivity/source/drivers/ado/ADatabaseMetaDataResultSet.cxx
@@ -182,7 +182,7 @@ Reference< ::com::sun::star::io::XInputStream > SAL_CALL ODatabaseMetaDataResult
Reference< ::com::sun::star::io::XInputStream > SAL_CALL ODatabaseMetaDataResultSet::getCharacterStream( sal_Int32 /*columnIndex*/ ) throw(SQLException, RuntimeException)
{
- ::dbtools::throwFeatureNotImplementedException( "XRow::getCharacterStream", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XRow::getCharacterStream", *this );
return NULL;
}
@@ -266,14 +266,14 @@ sal_Int32 SAL_CALL ODatabaseMetaDataResultSet::getInt( sal_Int32 columnIndex ) t
sal_Int32 SAL_CALL ODatabaseMetaDataResultSet::getRow( ) throw(SQLException, RuntimeException)
{
- ::dbtools::throwFeatureNotImplementedException( "XResultSet::getRow", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XResultSet::getRow", *this );
return 0;
}
sal_Int64 SAL_CALL ODatabaseMetaDataResultSet::getLong( sal_Int32 /*columnIndex*/ ) throw(SQLException, RuntimeException)
{
- ::dbtools::throwFeatureNotImplementedException( "XRow::getLong", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XRow::getLong", *this );
return sal_Int64(0);
}
@@ -294,7 +294,7 @@ Reference< XResultSetMetaData > SAL_CALL ODatabaseMetaDataResultSet::getMetaData
Reference< XArray > SAL_CALL ODatabaseMetaDataResultSet::getArray( sal_Int32 /*columnIndex*/ ) throw(SQLException, RuntimeException)
{
- ::dbtools::throwFeatureNotImplementedException( "XRow::getRow", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XRow::getRow", *this );
return NULL;
}
@@ -302,20 +302,20 @@ Reference< XArray > SAL_CALL ODatabaseMetaDataResultSet::getArray( sal_Int32 /*c
Reference< XClob > SAL_CALL ODatabaseMetaDataResultSet::getClob( sal_Int32 /*columnIndex*/ ) throw(SQLException, RuntimeException)
{
- ::dbtools::throwFeatureNotImplementedException( "XRow::getRow", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XRow::getRow", *this );
return NULL;
}
Reference< XBlob > SAL_CALL ODatabaseMetaDataResultSet::getBlob( sal_Int32 /*columnIndex*/ ) throw(SQLException, RuntimeException)
{
- ::dbtools::throwFeatureNotImplementedException( "XRow::getRow", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XRow::getRow", *this );
return NULL;
}
Reference< XRef > SAL_CALL ODatabaseMetaDataResultSet::getRef( sal_Int32 /*columnIndex*/ ) throw(SQLException, RuntimeException)
{
- ::dbtools::throwFeatureNotImplementedException( "XRow::getRow", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XRow::getRow", *this );
return NULL;
}
@@ -690,7 +690,7 @@ OUString ODatabaseMetaDataResultSet::getCursorName() const
void ODatabaseMetaDataResultSet::setFetchDirection(sal_Int32 /*_par0*/)
throw(::com::sun::star::sdbc::SQLException, ::com::sun::star::uno::RuntimeException)
{
- ::dbtools::throwFeatureNotImplementedException( "ResultSet::FetchDirection", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "ResultSet::FetchDirection", *this );
}
void ODatabaseMetaDataResultSet::setFetchSize(sal_Int32 _par0)
diff --git a/connectivity/source/drivers/ado/APreparedStatement.cxx b/connectivity/source/drivers/ado/APreparedStatement.cxx
index 71fbf0fc168b..12577dfd70ea 100644
--- a/connectivity/source/drivers/ado/APreparedStatement.cxx
+++ b/connectivity/source/drivers/ado/APreparedStatement.cxx
@@ -346,22 +346,22 @@ void SAL_CALL OPreparedStatement::setNull( sal_Int32 parameterIndex, sal_Int32 /
void SAL_CALL OPreparedStatement::setClob( sal_Int32 /*parameterIndex*/, const Reference< XClob >& /*x*/ ) throw(SQLException, RuntimeException)
{
- ::dbtools::throwFeatureNotImplementedException( "XRowUpdate::setClob", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XRowUpdate::setClob", *this );
}
void SAL_CALL OPreparedStatement::setBlob( sal_Int32 /*parameterIndex*/, const Reference< XBlob >& /*x*/ ) throw(SQLException, RuntimeException)
{
- ::dbtools::throwFeatureNotImplementedException( "XRowUpdate::setBlob", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XRowUpdate::setBlob", *this );
}
void SAL_CALL OPreparedStatement::setArray( sal_Int32 /*parameterIndex*/, const Reference< XArray >& /*x*/ ) throw(SQLException, RuntimeException)
{
- ::dbtools::throwFeatureNotImplementedException( "XRowUpdate::setArray", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XRowUpdate::setArray", *this );
}
void SAL_CALL OPreparedStatement::setRef( sal_Int32 /*parameterIndex*/, const Reference< XRef >& /*x*/ ) throw(SQLException, RuntimeException)
{
- ::dbtools::throwFeatureNotImplementedException( "XRowUpdate::setRef", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XRowUpdate::setRef", *this );
}
void SAL_CALL OPreparedStatement::setObjectWithInfo( sal_Int32 parameterIndex, const Any& x, sal_Int32 sqlType, sal_Int32 scale ) throw(SQLException, RuntimeException)
@@ -407,7 +407,7 @@ void SAL_CALL OPreparedStatement::setBytes( sal_Int32 parameterIndex, const Sequ
void SAL_CALL OPreparedStatement::setCharacterStream( sal_Int32 /*parameterIndex*/, const Reference< ::com::sun::star::io::XInputStream >& /*x*/, sal_Int32 /*length*/ ) throw(SQLException, RuntimeException)
{
- ::dbtools::throwFeatureNotImplementedException( "XParameters::setCharacterStream", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XParameters::setCharacterStream", *this );
}
void SAL_CALL OPreparedStatement::setBinaryStream( sal_Int32 parameterIndex, const Reference< ::com::sun::star::io::XInputStream >& x, sal_Int32 length ) throw(SQLException, RuntimeException)
diff --git a/connectivity/source/drivers/ado/AResultSet.cxx b/connectivity/source/drivers/ado/AResultSet.cxx
index 7ccbc5ecf50e..18de01330444 100644
--- a/connectivity/source/drivers/ado/AResultSet.cxx
+++ b/connectivity/source/drivers/ado/AResultSet.cxx
@@ -212,7 +212,7 @@ Reference< ::com::sun::star::io::XInputStream > SAL_CALL OResultSet::getBinarySt
Reference< ::com::sun::star::io::XInputStream > SAL_CALL OResultSet::getCharacterStream( sal_Int32 /*columnIndex*/ ) throw(SQLException, RuntimeException)
{
- ::dbtools::throwFeatureNotImplementedException( "XRow::getCharacterStream", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XRow::getCharacterStream", *this );
return NULL;
}
@@ -283,7 +283,7 @@ sal_Int32 SAL_CALL OResultSet::getRow( ) throw(SQLException, RuntimeException)
sal_Int64 SAL_CALL OResultSet::getLong( sal_Int32 /*columnIndex*/ ) throw(SQLException, RuntimeException)
{
- ::dbtools::throwFeatureNotImplementedException( "XRow::getLong", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XRow::getLong", *this );
return sal_Int64(0);
}
@@ -301,7 +301,7 @@ Reference< XResultSetMetaData > SAL_CALL OResultSet::getMetaData( ) throw(SQLEx
Reference< XArray > SAL_CALL OResultSet::getArray( sal_Int32 /*columnIndex*/ ) throw(SQLException, RuntimeException)
{
- ::dbtools::throwFeatureNotImplementedException( "XRow::getArray", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XRow::getArray", *this );
return NULL;
}
@@ -309,20 +309,20 @@ Reference< XArray > SAL_CALL OResultSet::getArray( sal_Int32 /*columnIndex*/ ) t
Reference< XClob > SAL_CALL OResultSet::getClob( sal_Int32 /*columnIndex*/ ) throw(SQLException, RuntimeException)
{
- ::dbtools::throwFeatureNotImplementedException( "XRow::getClob", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XRow::getClob", *this );
return NULL;
}
Reference< XBlob > SAL_CALL OResultSet::getBlob( sal_Int32 /*columnIndex*/ ) throw(SQLException, RuntimeException)
{
- ::dbtools::throwFeatureNotImplementedException( "XRow::getBlob", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XRow::getBlob", *this );
return NULL;
}
Reference< XRef > SAL_CALL OResultSet::getRef( sal_Int32 /*columnIndex*/ ) throw(SQLException, RuntimeException)
{
- ::dbtools::throwFeatureNotImplementedException( "XRow::getRef", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XRow::getRef", *this );
return NULL;
}
@@ -1043,7 +1043,7 @@ OUString OResultSet::getCursorName() const
void OResultSet::setFetchDirection(sal_Int32 /*_par0*/)
throw(::com::sun::star::sdbc::SQLException, ::com::sun::star::uno::RuntimeException)
{
- ::dbtools::throwFeatureNotImplementedException( "ResultSet::FetchDirection", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "ResultSet::FetchDirection", *this );
}
void OResultSet::setFetchSize(sal_Int32 _par0)
diff --git a/connectivity/source/drivers/ado/AStatement.cxx b/connectivity/source/drivers/ado/AStatement.cxx
index 830040f255e4..ad4244e69272 100644
--- a/connectivity/source/drivers/ado/AStatement.cxx
+++ b/connectivity/source/drivers/ado/AStatement.cxx
@@ -621,7 +621,7 @@ void OStatement_Base::setFetchDirection(sal_Int32 /*_par0*/) throw(SQLException,
{
::osl::MutexGuard aGuard( m_aMutex );
checkDisposed(OStatement_BASE::rBHelper.bDisposed);
- ::dbtools::throwFeatureNotImplementedException( "Statement::FetchDirection", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "Statement::FetchDirection", *this );
}
void OStatement_Base::setFetchSize(sal_Int32 _par0) throw(SQLException, RuntimeException)
@@ -637,7 +637,7 @@ void OStatement_Base::setMaxFieldSize(sal_Int32 /*_par0*/) throw(SQLException, R
{
::osl::MutexGuard aGuard( m_aMutex );
checkDisposed(OStatement_BASE::rBHelper.bDisposed);
- ::dbtools::throwFeatureNotImplementedException( "Statement::MaxFieldSize", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "Statement::MaxFieldSize", *this );
}
void OStatement_Base::setCursorName(const OUString &_par0) throw(SQLException, RuntimeException)
diff --git a/connectivity/source/drivers/calc/CConnection.cxx b/connectivity/source/drivers/calc/CConnection.cxx
index b81a58564f17..c71f345ca40a 100644
--- a/connectivity/source/drivers/calc/CConnection.cxx
+++ b/connectivity/source/drivers/calc/CConnection.cxx
@@ -259,7 +259,7 @@ Reference< XPreparedStatement > SAL_CALL OCalcConnection::prepareCall( const OUS
::osl::MutexGuard aGuard( m_aMutex );
checkDisposed(OConnection_BASE::rBHelper.bDisposed);
- ::dbtools::throwFeatureNotImplementedException( "XConnection::prepareCall", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XConnection::prepareCall", *this );
return NULL;
}
diff --git a/connectivity/source/drivers/calc/CResultSet.cxx b/connectivity/source/drivers/calc/CResultSet.cxx
index e0748bb83c88..236c1702d27a 100644
--- a/connectivity/source/drivers/calc/CResultSet.cxx
+++ b/connectivity/source/drivers/calc/CResultSet.cxx
@@ -133,7 +133,7 @@ Sequence< sal_Int32 > SAL_CALL OCalcResultSet::deleteRows( const Sequence< Any
::osl::MutexGuard aGuard( m_aMutex );
checkDisposed(OResultSet_BASE::rBHelper.bDisposed);
- ::dbtools::throwFeatureNotImplementedException( "XDeleteRows::deleteRows", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XDeleteRows::deleteRows", *this );
return Sequence< sal_Int32 >();
}
diff --git a/connectivity/source/drivers/dbase/DConnection.cxx b/connectivity/source/drivers/dbase/DConnection.cxx
index bbe93cfa9790..a86c316cddaa 100644
--- a/connectivity/source/drivers/dbase/DConnection.cxx
+++ b/connectivity/source/drivers/dbase/DConnection.cxx
@@ -109,7 +109,7 @@ Reference< XPreparedStatement > SAL_CALL ODbaseConnection::prepareStatement( con
Reference< XPreparedStatement > SAL_CALL ODbaseConnection::prepareCall( const OUString& /*sql*/ ) throw(SQLException, RuntimeException, std::exception)
{
- ::dbtools::throwFeatureNotImplementedException( "XConnection::prepareCall", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XConnection::prepareCall", *this );
return NULL;
}
diff --git a/connectivity/source/drivers/dbase/DResultSet.cxx b/connectivity/source/drivers/dbase/DResultSet.cxx
index 2d7652d61fcd..148b6baecc2d 100644
--- a/connectivity/source/drivers/dbase/DResultSet.cxx
+++ b/connectivity/source/drivers/dbase/DResultSet.cxx
@@ -154,7 +154,7 @@ Sequence< sal_Int32 > SAL_CALL ODbaseResultSet::deleteRows( const Sequence< An
::osl::MutexGuard aGuard( m_aMutex );
checkDisposed(OResultSet_BASE::rBHelper.bDisposed);
- ::dbtools::throwFeatureNotImplementedException( "XDeleteRows::deleteRows", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XDeleteRows::deleteRows", *this );
return Sequence< sal_Int32 >();
}
diff --git a/connectivity/source/drivers/evoab2/NConnection.cxx b/connectivity/source/drivers/evoab2/NConnection.cxx
index 67204db0f049..c6f00509e4d2 100644
--- a/connectivity/source/drivers/evoab2/NConnection.cxx
+++ b/connectivity/source/drivers/evoab2/NConnection.cxx
@@ -160,7 +160,7 @@ Reference< XPreparedStatement > SAL_CALL OEvoabConnection::prepareStatement( con
Reference< XPreparedStatement > SAL_CALL OEvoabConnection::prepareCall( const OUString& /*sql*/ ) throw( SQLException, RuntimeException, std::exception)
{
- ::dbtools::throwFeatureNotImplementedException( "XConnection::prepareCall", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XConnection::prepareCall", *this );
return NULL;
}
sal_Bool SAL_CALL OEvoabConnection::isClosed( ) throw(SQLException, RuntimeException, std::exception)
@@ -203,7 +203,7 @@ void OEvoabConnection::disposing()
// -------------------------------- stubbed methods ------------------------------------------------
void SAL_CALL OEvoabConnection::setAutoCommit( sal_Bool /*autoCommit*/ ) throw(SQLException, RuntimeException, std::exception)
{
- ::dbtools::throwFeatureNotImplementedException( "XConnection::setAutoCommit", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XConnection::setAutoCommit", *this );
}
sal_Bool SAL_CALL OEvoabConnection::getAutoCommit( ) throw(SQLException, RuntimeException, std::exception)
{
@@ -217,7 +217,7 @@ void SAL_CALL OEvoabConnection::rollback( ) throw(SQLException, RuntimeExceptio
}
void SAL_CALL OEvoabConnection::setReadOnly( sal_Bool /*readOnly*/ ) throw(SQLException, RuntimeException, std::exception)
{
- ::dbtools::throwFeatureNotImplementedException( "XConnection::setReadOnly", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XConnection::setReadOnly", *this );
}
sal_Bool SAL_CALL OEvoabConnection::isReadOnly( ) throw(SQLException, RuntimeException, std::exception)
{
@@ -225,7 +225,7 @@ sal_Bool SAL_CALL OEvoabConnection::isReadOnly( ) throw(SQLException, RuntimeEx
}
void SAL_CALL OEvoabConnection::setCatalog( const OUString& /*catalog*/ ) throw(SQLException, RuntimeException, std::exception)
{
- ::dbtools::throwFeatureNotImplementedException( "XConnection::setCatalog", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XConnection::setCatalog", *this );
}
OUString SAL_CALL OEvoabConnection::getCatalog( ) throw(SQLException, RuntimeException, std::exception)
@@ -234,7 +234,7 @@ OUString SAL_CALL OEvoabConnection::getCatalog( ) throw(SQLException, RuntimeEx
}
void SAL_CALL OEvoabConnection::setTransactionIsolation( sal_Int32 /*level*/ ) throw(SQLException, RuntimeException, std::exception)
{
- ::dbtools::throwFeatureNotImplementedException( "XConnection::setTransactionIsolation", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XConnection::setTransactionIsolation", *this );
}
sal_Int32 SAL_CALL OEvoabConnection::getTransactionIsolation( ) throw(SQLException, RuntimeException, std::exception)
@@ -244,12 +244,12 @@ sal_Int32 SAL_CALL OEvoabConnection::getTransactionIsolation( ) throw(SQLExcept
Reference< ::com::sun::star::container::XNameAccess > SAL_CALL OEvoabConnection::getTypeMap( ) throw(SQLException, RuntimeException, std::exception)
{
- ::dbtools::throwFeatureNotImplementedException( "XConnection::getTypeMap", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XConnection::getTypeMap", *this );
return NULL;
}
void SAL_CALL OEvoabConnection::setTypeMap( const Reference< ::com::sun::star::container::XNameAccess >& /*typeMap*/ ) throw(SQLException, RuntimeException, std::exception)
{
- ::dbtools::throwFeatureNotImplementedException( "XConnection::setTypeMap", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XConnection::setTypeMap", *this );
}
/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
diff --git a/connectivity/source/drivers/evoab2/NDatabaseMetaData.cxx b/connectivity/source/drivers/evoab2/NDatabaseMetaData.cxx
index bbc3f0194d69..12605cb3878b 100644
--- a/connectivity/source/drivers/evoab2/NDatabaseMetaData.cxx
+++ b/connectivity/source/drivers/evoab2/NDatabaseMetaData.cxx
@@ -1227,7 +1227,7 @@ Reference< XResultSet > SAL_CALL OEvoabDatabaseMetaData::getTables(
Reference< XResultSet > SAL_CALL OEvoabDatabaseMetaData::getUDTs( const Any& /*catalog*/, const OUString& /*schemaPattern*/, const OUString& /*typeNamePattern*/, const Sequence< sal_Int32 >& /*types*/ ) throw(SQLException, RuntimeException, std::exception)
{
- ::dbtools::throwFeatureNotImplementedException( "XDatabaseMetaDaza::getUDTs", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XDatabaseMetaDaza::getUDTs", *this );
return NULL;
}
diff --git a/connectivity/source/drivers/evoab2/NPreparedStatement.cxx b/connectivity/source/drivers/evoab2/NPreparedStatement.cxx
index a7e72c84c802..ece475a29484 100644
--- a/connectivity/source/drivers/evoab2/NPreparedStatement.cxx
+++ b/connectivity/source/drivers/evoab2/NPreparedStatement.cxx
@@ -140,7 +140,7 @@ sal_Int32 SAL_CALL OEvoabPreparedStatement::executeUpdate( ) throw(SQLException
{
::osl::MutexGuard aGuard( m_aMutex );
checkDisposed(OCommonStatement_IBase::rBHelper.bDisposed);
- ::dbtools::throwFeatureNotImplementedException( "XStatement::executeUpdate", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XStatement::executeUpdate", *this );
return 0;
}
diff --git a/connectivity/source/drivers/evoab2/NStatement.cxx b/connectivity/source/drivers/evoab2/NStatement.cxx
index a0b2ccf48795..4d7ad92e496c 100644
--- a/connectivity/source/drivers/evoab2/NStatement.cxx
+++ b/connectivity/source/drivers/evoab2/NStatement.cxx
@@ -634,7 +634,7 @@ sal_Int32 SAL_CALL OStatement::executeUpdate( const OUString& /*sql*/ ) throw(SQ
{
::osl::MutexGuard aGuard( m_aMutex );
checkDisposed(OCommonStatement_IBase::rBHelper.bDisposed);
- ::dbtools::throwFeatureNotImplementedException( "XStatement::executeUpdate", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XStatement::executeUpdate", *this );
return 0;
}
diff --git a/connectivity/source/drivers/file/FConnection.cxx b/connectivity/source/drivers/file/FConnection.cxx
index bd6d0a4db80d..dbb3c675a516 100644
--- a/connectivity/source/drivers/file/FConnection.cxx
+++ b/connectivity/source/drivers/file/FConnection.cxx
@@ -245,7 +245,7 @@ Reference< XPreparedStatement > SAL_CALL OConnection::prepareStatement( const OU
Reference< XPreparedStatement > SAL_CALL OConnection::prepareCall( const OUString& /*sql*/ ) throw(SQLException, RuntimeException, std::exception)
{
- throwFeatureNotImplementedException( "XConnection::prepareCall", *this );
+ throwFeatureNotImplementedSQLException( "XConnection::prepareCall", *this );
return NULL;
}
@@ -321,7 +321,7 @@ sal_Bool SAL_CALL OConnection::isReadOnly( ) throw(SQLException, RuntimeExcepti
void SAL_CALL OConnection::setCatalog( const OUString& /*catalog*/ ) throw(SQLException, RuntimeException, std::exception)
{
- throwFeatureNotImplementedException( "XConnection::setCatalog", *this );
+ throwFeatureNotImplementedSQLException( "XConnection::setCatalog", *this );
}
OUString SAL_CALL OConnection::getCatalog( ) throw(SQLException, RuntimeException, std::exception)
@@ -331,7 +331,7 @@ OUString SAL_CALL OConnection::getCatalog( ) throw(SQLException, RuntimeExcepti
void SAL_CALL OConnection::setTransactionIsolation( sal_Int32 /*level*/ ) throw(SQLException, RuntimeException, std::exception)
{
- throwFeatureNotImplementedException( "XConnection::setTransactionIsolation", *this );
+ throwFeatureNotImplementedSQLException( "XConnection::setTransactionIsolation", *this );
}
sal_Int32 SAL_CALL OConnection::getTransactionIsolation( ) throw(SQLException, RuntimeException, std::exception)
diff --git a/connectivity/source/drivers/file/FPreparedStatement.cxx b/connectivity/source/drivers/file/FPreparedStatement.cxx
index 5e166db428f7..7d5e1c5cc496 100644
--- a/connectivity/source/drivers/file/FPreparedStatement.cxx
+++ b/connectivity/source/drivers/file/FPreparedStatement.cxx
@@ -255,7 +255,7 @@ void SAL_CALL OPreparedStatement::setInt( sal_Int32 parameterIndex, sal_Int32 x
void SAL_CALL OPreparedStatement::setLong( sal_Int32 /*parameterIndex*/, sal_Int64 /*aVal*/ ) throw(SQLException, RuntimeException, std::exception)
{
- throwFeatureNotImplementedException( "XParameters::setLong", *this );
+ throwFeatureNotImplementedSQLException( "XParameters::setLong", *this );
}
@@ -273,25 +273,25 @@ void SAL_CALL OPreparedStatement::setNull( sal_Int32 parameterIndex, sal_Int32 /
void SAL_CALL OPreparedStatement::setClob( sal_Int32 /*parameterIndex*/, const Reference< XClob >& /*x*/ ) throw(SQLException, RuntimeException, std::exception)
{
- throwFeatureNotImplementedException( "XParameters::setClob", *this );
+ throwFeatureNotImplementedSQLException( "XParameters::setClob", *this );
}
void SAL_CALL OPreparedStatement::setBlob( sal_Int32 /*parameterIndex*/, const Reference< XBlob >& /*x*/ ) throw(SQLException, RuntimeException, std::exception)
{
- throwFeatureNotImplementedException( "XParameters::setBlob", *this );
+ throwFeatureNotImplementedSQLException( "XParameters::setBlob", *this );
}
void SAL_CALL OPreparedStatement::setArray( sal_Int32 /*parameterIndex*/, const Reference< XArray >& /*x*/ ) throw(SQLException, RuntimeException, std::exception)
{
- throwFeatureNotImplementedException( "XParameters::setArray", *this );
+ throwFeatureNotImplementedSQLException( "XParameters::setArray", *this );
}
void SAL_CALL OPreparedStatement::setRef( sal_Int32 /*parameterIndex*/, const Reference< XRef >& /*x*/ ) throw(SQLException, RuntimeException, std::exception)
{
- throwFeatureNotImplementedException( "XParameters::setRef", *this );
+ throwFeatureNotImplementedSQLException( "XParameters::setRef", *this );
}
diff --git a/connectivity/source/drivers/file/FResultSet.cxx b/connectivity/source/drivers/file/FResultSet.cxx
index 14fa3318e06e..589ecd3bd279 100644
--- a/connectivity/source/drivers/file/FResultSet.cxx
+++ b/connectivity/source/drivers/file/FResultSet.cxx
@@ -711,7 +711,7 @@ void SAL_CALL OResultSet::updateInt( sal_Int32 columnIndex, sal_Int32 x ) throw(
void SAL_CALL OResultSet::updateLong( sal_Int32 /*columnIndex*/, sal_Int64 /*x*/ ) throw(SQLException, RuntimeException, std::exception)
{
- ::dbtools::throwFeatureNotImplementedException( "XRowUpdate::updateLong", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XRowUpdate::updateLong", *this );
}
void SAL_CALL OResultSet::updateFloat( sal_Int32 columnIndex, float x ) throw(SQLException, RuntimeException, std::exception)
diff --git a/connectivity/source/drivers/firebird/Blob.cxx b/connectivity/source/drivers/firebird/Blob.cxx
index 95ecc54a5aa0..7d62bbc7da5f 100644
--- a/connectivity/source/drivers/firebird/Blob.cxx
+++ b/connectivity/source/drivers/firebird/Blob.cxx
@@ -171,7 +171,7 @@ sal_Int64 SAL_CALL Blob::position(const uno::Sequence< sal_Int8 >& /*rPattern*/
sal_Int64 /*nStart*/)
throw(SQLException, RuntimeException, std::exception)
{
- ::dbtools::throwFeatureNotImplementedException("Blob::position", *this);
+ ::dbtools::throwFeatureNotImplementedSQLException("Blob::position", *this);
return 0;
}
@@ -179,7 +179,7 @@ sal_Int64 SAL_CALL Blob::positionOfBlob(const uno::Reference< XBlob >& /*rPatte
sal_Int64 /*aStart*/)
throw(SQLException, RuntimeException, std::exception)
{
- ::dbtools::throwFeatureNotImplementedException("Blob::positionOfBlob", *this);
+ ::dbtools::throwFeatureNotImplementedSQLException("Blob::positionOfBlob", *this);
return 0;
}
diff --git a/connectivity/source/drivers/firebird/Connection.cxx b/connectivity/source/drivers/firebird/Connection.cxx
index 14e5a5a104f7..caf62f863337 100644
--- a/connectivity/source/drivers/firebird/Connection.cxx
+++ b/connectivity/source/drivers/firebird/Connection.cxx
@@ -604,14 +604,14 @@ sal_Int32 SAL_CALL Connection::getTransactionIsolation( ) throw(SQLException, R
Reference< XNameAccess > SAL_CALL Connection::getTypeMap() throw(SQLException, RuntimeException, std::exception)
{
- ::dbtools::throwFeatureNotImplementedException( "XConnection::getTypeMap", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XConnection::getTypeMap", *this );
return 0;
}
void SAL_CALL Connection::setTypeMap(const Reference< XNameAccess >& typeMap)
throw(SQLException, RuntimeException, std::exception)
{
- ::dbtools::throwFeatureNotImplementedException( "XConnection::setTypeMap", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XConnection::setTypeMap", *this );
(void) typeMap;
}
diff --git a/connectivity/source/drivers/flat/EConnection.cxx b/connectivity/source/drivers/flat/EConnection.cxx
index 03bb821ff844..37d1d7877751 100644
--- a/connectivity/source/drivers/flat/EConnection.cxx
+++ b/connectivity/source/drivers/flat/EConnection.cxx
@@ -165,7 +165,7 @@ Reference< XPreparedStatement > SAL_CALL OFlatConnection::prepareCall( const OUS
::osl::MutexGuard aGuard( m_aMutex );
checkDisposed(OConnection_B::rBHelper.bDisposed);
- ::dbtools::throwFeatureNotImplementedException( "XConnection::prepareCall", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XConnection::prepareCall", *this );
return NULL;
}
diff --git a/connectivity/source/drivers/hsqldb/HDriver.cxx b/connectivity/source/drivers/hsqldb/HDriver.cxx
index b78c6c16efa7..b63e421b328f 100644
--- a/connectivity/source/drivers/hsqldb/HDriver.cxx
+++ b/connectivity/source/drivers/hsqldb/HDriver.cxx
@@ -530,7 +530,7 @@ namespace connectivity
void SAL_CALL ODriverDelegator::createCatalog( const Sequence< PropertyValue >& /*info*/ ) throw (SQLException, ::com::sun::star::container::ElementExistException, RuntimeException, std::exception)
{
- ::dbtools::throwFeatureNotImplementedException( "XCreateCatalog::createCatalog", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XCreateCatalog::createCatalog", *this );
}
void ODriverDelegator::shutdownConnection(const TWeakPairVector::iterator& _aIter )
diff --git a/connectivity/source/drivers/jdbc/Blob.cxx b/connectivity/source/drivers/jdbc/Blob.cxx
index 5795053165f7..a76831aa0380 100644
--- a/connectivity/source/drivers/jdbc/Blob.cxx
+++ b/connectivity/source/drivers/jdbc/Blob.cxx
@@ -124,7 +124,7 @@ sal_Int64 SAL_CALL java_sql_Blob::position( const ::com::sun::star::uno::Sequenc
sal_Int64 SAL_CALL java_sql_Blob::positionOfBlob( const ::com::sun::star::uno::Reference< ::com::sun::star::sdbc::XBlob >& /*pattern*/, sal_Int64 /*start*/ ) throw(::com::sun::star::sdbc::SQLException, ::com::sun::star::uno::RuntimeException, std::exception)
{
- ::dbtools::throwFeatureNotImplementedException( "XBlob::positionOfBlob", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XBlob::positionOfBlob", *this );
// this was put here in CWS warnings01. The previous implementation was defective, as it did ignore
// the pattern parameter. Since the effort for proper implementation is rather high - we would need
// to translated patter into a byte[] -, we defer this functionality for the moment (hey, it was
diff --git a/connectivity/source/drivers/jdbc/Clob.cxx b/connectivity/source/drivers/jdbc/Clob.cxx
index dc722a10285e..842ae71caede 100644
--- a/connectivity/source/drivers/jdbc/Clob.cxx
+++ b/connectivity/source/drivers/jdbc/Clob.cxx
@@ -118,7 +118,7 @@ sal_Int64 SAL_CALL java_sql_Clob::position( const OUString& searchstr, sal_Int32
sal_Int64 SAL_CALL java_sql_Clob::positionOfClob( const ::com::sun::star::uno::Reference< ::com::sun::star::sdbc::XClob >& /*pattern*/, sal_Int64 /*start*/ ) throw(::com::sun::star::sdbc::SQLException, ::com::sun::star::uno::RuntimeException, std::exception)
{
- ::dbtools::throwFeatureNotImplementedException( "XClob::positionOfClob", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XClob::positionOfClob", *this );
// this was put here in CWS warnings01. The previous implementation was defective, as it did ignore
// the pattern parameter. Since the effort for proper implementation is rather high - we would need
// to translated patter into a byte[] -, we defer this functionality for the moment (hey, it was
diff --git a/connectivity/source/drivers/jdbc/JConnection.cxx b/connectivity/source/drivers/jdbc/JConnection.cxx
index 8886d7abfbaf..a4b0febad225 100644
--- a/connectivity/source/drivers/jdbc/JConnection.cxx
+++ b/connectivity/source/drivers/jdbc/JConnection.cxx
@@ -427,7 +427,7 @@ void SAL_CALL java_sql_Connection::setTypeMap( const Reference< ::com::sun::star
::osl::MutexGuard aGuard( m_aMutex );
checkDisposed(java_sql_Connection_BASE::rBHelper.bDisposed);
- ::dbtools::throwFeatureNotImplementedException( "XConnection::setTypeMap", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XConnection::setTypeMap", *this );
}
diff --git a/connectivity/source/drivers/jdbc/PreparedStatement.cxx b/connectivity/source/drivers/jdbc/PreparedStatement.cxx
index 04d9f621e315..6da0c5794b60 100644
--- a/connectivity/source/drivers/jdbc/PreparedStatement.cxx
+++ b/connectivity/source/drivers/jdbc/PreparedStatement.cxx
@@ -295,25 +295,25 @@ void SAL_CALL java_sql_PreparedStatement::setNull( sal_Int32 parameterIndex, sal
void SAL_CALL java_sql_PreparedStatement::setClob( sal_Int32 /*parameterIndex*/, const ::com::sun::star::uno::Reference< ::com::sun::star::sdbc::XClob >& /*x*/ ) throw(::com::sun::star::sdbc::SQLException, ::com::sun::star::uno::RuntimeException, std::exception)
{
- ::dbtools::throwFeatureNotImplementedException( "XParameters::setClob", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XParameters::setClob", *this );
}
void SAL_CALL java_sql_PreparedStatement::setBlob( sal_Int32 /*parameterIndex*/, const ::com::sun::star::uno::Reference< ::com::sun::star::sdbc::XBlob >& /*x*/ ) throw(::com::sun::star::sdbc::SQLException, ::com::sun::star::uno::RuntimeException, std::exception)
{
- ::dbtools::throwFeatureNotImplementedException( "XParameters::setBlob", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XParameters::setBlob", *this );
}
void SAL_CALL java_sql_PreparedStatement::setArray( sal_Int32 /*parameterIndex*/, const ::com::sun::star::uno::Reference< ::com::sun::star::sdbc::XArray >& /*x*/ ) throw(::com::sun::star::sdbc::SQLException, ::com::sun::star::uno::RuntimeException, std::exception)
{
- ::dbtools::throwFeatureNotImplementedException( "XParameters::setArray", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XParameters::setArray", *this );
}
void SAL_CALL java_sql_PreparedStatement::setRef( sal_Int32 /*parameterIndex*/, const ::com::sun::star::uno::Reference< ::com::sun::star::sdbc::XRef >& /*x*/ ) throw(::com::sun::star::sdbc::SQLException, ::com::sun::star::uno::RuntimeException, std::exception)
{
- ::dbtools::throwFeatureNotImplementedException( "XParameters::setRef", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XParameters::setRef", *this );
}
diff --git a/connectivity/source/drivers/jdbc/ResultSet.cxx b/connectivity/source/drivers/jdbc/ResultSet.cxx
index 1f8b0cc4c9c3..8f87b173ee70 100644
--- a/connectivity/source/drivers/jdbc/ResultSet.cxx
+++ b/connectivity/source/drivers/jdbc/ResultSet.cxx
@@ -730,7 +730,7 @@ void SAL_CALL java_sql_ResultSet::updateBinaryStream( sal_Int32 columnIndex, con
}
catch(const Exception&)
{
- ::dbtools::throwFeatureNotImplementedException( "XRowUpdate::updateBinaryStream", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XRowUpdate::updateBinaryStream", *this );
}
}
@@ -761,7 +761,7 @@ void SAL_CALL java_sql_ResultSet::updateCharacterStream( sal_Int32 columnIndex,
}
catch(const Exception&)
{
- ::dbtools::throwFeatureNotImplementedException( "XRowUpdate::updateCharacterStream", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XRowUpdate::updateCharacterStream", *this );
}
}
diff --git a/connectivity/source/drivers/jdbc/tools.cxx b/connectivity/source/drivers/jdbc/tools.cxx
index 5d993308dbff..6c569f2909f9 100644
--- a/connectivity/source/drivers/jdbc/tools.cxx
+++ b/connectivity/source/drivers/jdbc/tools.cxx
@@ -178,7 +178,7 @@ jobject connectivity::convertTypeMapToJavaMap(JNIEnv* /*pEnv*/,const Reference<
{
::com::sun::star::uno::Sequence< OUString > aNames = _rMap->getElementNames();
if ( aNames.getLength() > 0 )
- ::dbtools::throwFeatureNotImplementedException( "Type maps", NULL );
+ ::dbtools::throwFeatureNotImplementedSQLException( "Type maps", NULL );
}
return 0;
}
diff --git a/connectivity/source/drivers/mork/MConnection.cxx b/connectivity/source/drivers/mork/MConnection.cxx
index e84d55f9a23d..2c5748b06f48 100644
--- a/connectivity/source/drivers/mork/MConnection.cxx
+++ b/connectivity/source/drivers/mork/MConnection.cxx
@@ -215,7 +215,7 @@ Reference< XPreparedStatement > SAL_CALL OConnection::prepareCall( const OUStrin
SAL_INFO("connectivity.mork", "=> OConnection::prepareCall()" );
SAL_INFO("connectivity.mork", "sql: " << _sSql);
OSL_UNUSED( _sSql );
- ::dbtools::throwFeatureNotImplementedException( "XConnection::prepareCall", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XConnection::prepareCall", *this );
SAL_INFO("connectivity.mork", "OConnection::prepareCall( " << _sSql << " )");
return NULL;
}
@@ -234,7 +234,7 @@ OUString SAL_CALL OConnection::nativeSQL( const OUString& _sSql ) throw(SQLExcep
void SAL_CALL OConnection::setAutoCommit( sal_Bool /*autoCommit*/ ) throw(SQLException, RuntimeException, std::exception)
{
- ::dbtools::throwFeatureNotImplementedException( "XConnection::setAutoCommit", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XConnection::setAutoCommit", *this );
}
sal_Bool SAL_CALL OConnection::getAutoCommit( ) throw(SQLException, RuntimeException, std::exception)
@@ -284,7 +284,7 @@ Reference< XDatabaseMetaData > SAL_CALL OConnection::getMetaData( ) throw(SQLEx
void SAL_CALL OConnection::setReadOnly( sal_Bool /*readOnly*/ ) throw(SQLException, RuntimeException, std::exception)
{
- ::dbtools::throwFeatureNotImplementedException( "XConnection::setReadOnly", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XConnection::setReadOnly", *this );
}
sal_Bool SAL_CALL OConnection::isReadOnly( ) throw(SQLException, RuntimeException, std::exception)
@@ -295,7 +295,7 @@ sal_Bool SAL_CALL OConnection::isReadOnly( ) throw(SQLException, RuntimeExcepti
void SAL_CALL OConnection::setCatalog( const OUString& /*catalog*/ ) throw(SQLException, RuntimeException, std::exception)
{
- ::dbtools::throwFeatureNotImplementedException( "XConnection::setCatalog", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XConnection::setCatalog", *this );
}
OUString SAL_CALL OConnection::getCatalog( ) throw(SQLException, RuntimeException, std::exception)
@@ -305,7 +305,7 @@ OUString SAL_CALL OConnection::getCatalog( ) throw(SQLException, RuntimeExcepti
void SAL_CALL OConnection::setTransactionIsolation( sal_Int32 /*level*/ ) throw(SQLException, RuntimeException, std::exception)
{
- ::dbtools::throwFeatureNotImplementedException( "XConnection::setTransactionIsolation", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XConnection::setTransactionIsolation", *this );
}
sal_Int32 SAL_CALL OConnection::getTransactionIsolation( ) throw(SQLException, RuntimeException, std::exception)
@@ -322,7 +322,7 @@ Reference< ::com::sun::star::container::XNameAccess > SAL_CALL OConnection::getT
void SAL_CALL OConnection::setTypeMap( const Reference< ::com::sun::star::container::XNameAccess >& /*typeMap*/ ) throw(SQLException, RuntimeException, std::exception)
{
- ::dbtools::throwFeatureNotImplementedException( "XConnection::setTypeMap", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XConnection::setTypeMap", *this );
}
// XCloseable
diff --git a/connectivity/source/drivers/mork/MPreparedStatement.cxx b/connectivity/source/drivers/mork/MPreparedStatement.cxx
index 742a13bbb3a8..2ed87e665e13 100644
--- a/connectivity/source/drivers/mork/MPreparedStatement.cxx
+++ b/connectivity/source/drivers/mork/MPreparedStatement.cxx
@@ -174,7 +174,7 @@ sal_Bool SAL_CALL OPreparedStatement::execute( ) throw(SQLException, RuntimeExc
sal_Int32 SAL_CALL OPreparedStatement::executeUpdate( ) throw(SQLException, RuntimeException, std::exception)
{
- ::dbtools::throwFeatureNotImplementedException( "XStatement::executeUpdate", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XStatement::executeUpdate", *this );
return 0;
}
@@ -212,56 +212,56 @@ Reference< XResultSet > SAL_CALL OPreparedStatement::executeQuery( ) throw(SQLE
void SAL_CALL OPreparedStatement::setBoolean( sal_Int32 /*parameterIndex*/, sal_Bool /*x*/ ) throw(SQLException, RuntimeException, std::exception)
{
- ::dbtools::throwFeatureNotImplementedException( "XParameters::setBoolean", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XParameters::setBoolean", *this );
}
void SAL_CALL OPreparedStatement::setByte( sal_Int32 /*parameterIndex*/, sal_Int8 /*x*/ ) throw(SQLException, RuntimeException, std::exception)
{
- ::dbtools::throwFeatureNotImplementedException( "XParameters::setByte", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XParameters::setByte", *this );
}
void SAL_CALL OPreparedStatement::setDate( sal_Int32 /*parameterIndex*/, const Date& /*aData*/ ) throw(SQLException, RuntimeException, std::exception)
{
- ::dbtools::throwFeatureNotImplementedException( "XParameters::setDate", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XParameters::setDate", *this );
}
void SAL_CALL OPreparedStatement::setTime( sal_Int32 /*parameterIndex*/, const Time& /*aVal*/ ) throw(SQLException, RuntimeException, std::exception)
{
- ::dbtools::throwFeatureNotImplementedException( "XParameters::setTime", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XParameters::setTime", *this );
}
void SAL_CALL OPreparedStatement::setTimestamp( sal_Int32 /*parameterIndex*/, const DateTime& /*aVal*/ ) throw(SQLException, RuntimeException, std::exception)
{
- ::dbtools::throwFeatureNotImplementedException( "XParameters::setTimestamp", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XParameters::setTimestamp", *this );
}
void SAL_CALL OPreparedStatement::setDouble( sal_Int32 /*parameterIndex*/, double /*x*/ ) throw(SQLException, RuntimeException, std::exception)
{
- ::dbtools::throwFeatureNotImplementedException( "XParameters::setDouble", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XParameters::setDouble", *this );
}
void SAL_CALL OPreparedStatement::setFloat( sal_Int32 /*parameterIndex*/, float /*x*/ ) throw(SQLException, RuntimeException, std::exception)
{
- ::dbtools::throwFeatureNotImplementedException( "XParameters::setFloat", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XParameters::setFloat", *this );
}
void SAL_CALL OPreparedStatement::setInt( sal_Int32 /*parameterIndex*/, sal_Int32 /*x*/ ) throw(SQLException, RuntimeException, std::exception)
{
- ::dbtools::throwFeatureNotImplementedException( "XParameters::setInt", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XParameters::setInt", *this );
}
void SAL_CALL OPreparedStatement::setLong( sal_Int32 /*parameterIndex*/, sal_Int64 /*aVal*/ ) throw(SQLException, RuntimeException, std::exception)
{
- ::dbtools::throwFeatureNotImplementedException( "XParameters::setLong", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XParameters::setLong", *this );
}
@@ -278,31 +278,31 @@ void SAL_CALL OPreparedStatement::setNull( sal_Int32 parameterIndex, sal_Int32 /
void SAL_CALL OPreparedStatement::setClob( sal_Int32 /*parameterIndex*/, const Reference< XClob >& /*x*/ ) throw(SQLException, RuntimeException, std::exception)
{
- ::dbtools::throwFeatureNotImplementedException( "XParameters::setClob", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XParameters::setClob", *this );
}
void SAL_CALL OPreparedStatement::setBlob( sal_Int32 /*parameterIndex*/, const Reference< XBlob >& /*x*/ ) throw(SQLException, RuntimeException, std::exception)
{
- ::dbtools::throwFeatureNotImplementedException( "XParameters::setBlob", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XParameters::setBlob", *this );
}
void SAL_CALL OPreparedStatement::setArray( sal_Int32 /*parameterIndex*/, const Reference< XArray >& /*x*/ ) throw(SQLException, RuntimeException, std::exception)
{
- ::dbtools::throwFeatureNotImplementedException( "XParameters::setArray", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XParameters::setArray", *this );
}
void SAL_CALL OPreparedStatement::setRef( sal_Int32 /*parameterIndex*/, const Reference< XRef >& /*x*/ ) throw(SQLException, RuntimeException, std::exception)
{
- ::dbtools::throwFeatureNotImplementedException( "XParameters::setRef", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XParameters::setRef", *this );
}
void SAL_CALL OPreparedStatement::setObjectWithInfo( sal_Int32 /*parameterIndex*/, const Any& /*x*/, sal_Int32 /*sqlType*/, sal_Int32 /*scale*/ ) throw(SQLException, RuntimeException, std::exception)
{
- ::dbtools::throwFeatureNotImplementedException( "XParameters::setObjectWithInfo", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XParameters::setObjectWithInfo", *this );
}
@@ -320,26 +320,26 @@ void SAL_CALL OPreparedStatement::setObject( sal_Int32 parameterIndex, const Any
void SAL_CALL OPreparedStatement::setShort( sal_Int32 /*parameterIndex*/, sal_Int16 /*x*/ ) throw(SQLException, RuntimeException, std::exception)
{
- ::dbtools::throwFeatureNotImplementedException( "XParameters::setShort", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XParameters::setShort", *this );
}
void SAL_CALL OPreparedStatement::setBytes( sal_Int32 /*parameterIndex*/, const Sequence< sal_Int8 >& /*x*/ ) throw(SQLException, RuntimeException, std::exception)
{
- ::dbtools::throwFeatureNotImplementedException( "XParameters::setBytes", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XParameters::setBytes", *this );
}
void SAL_CALL OPreparedStatement::setCharacterStream( sal_Int32 /*parameterIndex*/, const Reference< ::com::sun::star::io::XInputStream >& /*x*/, sal_Int32 /*length*/ ) throw(SQLException, RuntimeException, std::exception)
{
- ::dbtools::throwFeatureNotImplementedException( "XParameters::setCharacterStream", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XParameters::setCharacterStream", *this );
}
void SAL_CALL OPreparedStatement::setBinaryStream( sal_Int32 /*parameterIndex*/, const Reference< ::com::sun::star::io::XInputStream >& /*x*/, sal_Int32 /*length*/ ) throw(SQLException, RuntimeException, std::exception)
{
- ::dbtools::throwFeatureNotImplementedException( "XParameters::setBinaryStream", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XParameters::setBinaryStream", *this );
}
diff --git a/connectivity/source/drivers/mork/MResultSet.cxx b/connectivity/source/drivers/mork/MResultSet.cxx
index 8b1de5620a6e..da81055fa87f 100644
--- a/connectivity/source/drivers/mork/MResultSet.cxx
+++ b/connectivity/source/drivers/mork/MResultSet.cxx
@@ -1720,7 +1720,7 @@ void SAL_CALL OResultSet::updateInt( sal_Int32 columnIndex, sal_Int32 x ) throw(
void SAL_CALL OResultSet::updateLong( sal_Int32 /*columnIndex*/, sal_Int64 /*x*/ ) throw(SQLException, RuntimeException, std::exception)
{
- ::dbtools::throwFeatureNotImplementedException( "XRowUpdate::updateLong", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XRowUpdate::updateLong", *this );
}
void SAL_CALL OResultSet::updateFloat( sal_Int32 columnIndex, float x ) throw(SQLException, RuntimeException, std::exception)
@@ -1885,7 +1885,7 @@ void OResultSet::setOrderByAscending(const ::std::vector<TAscendingOrder>& _aOrd
}
Sequence< sal_Int32 > SAL_CALL OResultSet::deleteRows( const Sequence< Any >& /*rows*/ ) throw(SQLException, RuntimeException, std::exception)
{
- ::dbtools::throwFeatureNotImplementedException( "XDeleteRows::deleteRows", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XDeleteRows::deleteRows", *this );
return Sequence< sal_Int32 >();
};
diff --git a/connectivity/source/drivers/mork/MStatement.cxx b/connectivity/source/drivers/mork/MStatement.cxx
index d8f16a38d85e..ebff5ef2dc9f 100644
--- a/connectivity/source/drivers/mork/MStatement.cxx
+++ b/connectivity/source/drivers/mork/MStatement.cxx
@@ -356,7 +356,7 @@ Any SAL_CALL OStatement::queryInterface( const Type & rType ) throw(RuntimeExcep
sal_Int32 SAL_CALL OCommonStatement::executeUpdate( const OUString& /*sql*/ ) throw(SQLException, RuntimeException, std::exception)
{
- ::dbtools::throwFeatureNotImplementedException( "XStatement::executeUpdate", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XStatement::executeUpdate", *this );
return 0;
}
diff --git a/connectivity/source/drivers/mozab/MConnection.cxx b/connectivity/source/drivers/mozab/MConnection.cxx
index 75e2353aff1e..bf1fb63fd47a 100644
--- a/connectivity/source/drivers/mozab/MConnection.cxx
+++ b/connectivity/source/drivers/mozab/MConnection.cxx
@@ -376,7 +376,7 @@ Reference< XPreparedStatement > SAL_CALL OConnection::prepareStatement( const OU
Reference< XPreparedStatement > SAL_CALL OConnection::prepareCall( const OUString& _sSql ) throw(SQLException, RuntimeException)
{
OSL_UNUSED( _sSql );
- ::dbtools::throwFeatureNotImplementedException( "XConnection::prepareCall", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XConnection::prepareCall", *this );
OSL_TRACE("OConnection::prepareCall( %s )", OUtoCStr( _sSql ) );
return NULL;
}
@@ -392,7 +392,7 @@ OUString SAL_CALL OConnection::nativeSQL( const OUString& _sSql ) throw(SQLExcep
void SAL_CALL OConnection::setAutoCommit( sal_Bool /*autoCommit*/ ) throw(SQLException, RuntimeException)
{
- ::dbtools::throwFeatureNotImplementedException( "XConnection::setAutoCommit", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XConnection::setAutoCommit", *this );
}
sal_Bool SAL_CALL OConnection::getAutoCommit( ) throw(SQLException, RuntimeException)
@@ -440,7 +440,7 @@ Reference< XDatabaseMetaData > SAL_CALL OConnection::getMetaData( ) throw(SQLEx
void SAL_CALL OConnection::setReadOnly( sal_Bool /*readOnly*/ ) throw(SQLException, RuntimeException)
{
- ::dbtools::throwFeatureNotImplementedException( "XConnection::setReadOnly", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XConnection::setReadOnly", *this );
}
sal_Bool SAL_CALL OConnection::isReadOnly( ) throw(SQLException, RuntimeException)
@@ -451,7 +451,7 @@ sal_Bool SAL_CALL OConnection::isReadOnly( ) throw(SQLException, RuntimeExcepti
void SAL_CALL OConnection::setCatalog( const OUString& /*catalog*/ ) throw(SQLException, RuntimeException)
{
- ::dbtools::throwFeatureNotImplementedException( "XConnection::setCatalog", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XConnection::setCatalog", *this );
}
OUString SAL_CALL OConnection::getCatalog( ) throw(SQLException, RuntimeException)
@@ -462,7 +462,7 @@ OUString SAL_CALL OConnection::getCatalog( ) throw(SQLException, RuntimeExcepti
void SAL_CALL OConnection::setTransactionIsolation( sal_Int32 /*level*/ ) throw(SQLException, RuntimeException)
{
- ::dbtools::throwFeatureNotImplementedException( "XConnection::setTransactionIsolation", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XConnection::setTransactionIsolation", *this );
}
sal_Int32 SAL_CALL OConnection::getTransactionIsolation( ) throw(SQLException, RuntimeException)
@@ -479,7 +479,7 @@ Reference< ::com::sun::star::container::XNameAccess > SAL_CALL OConnection::getT
void SAL_CALL OConnection::setTypeMap( const Reference< ::com::sun::star::container::XNameAccess >& /*typeMap*/ ) throw(SQLException, RuntimeException)
{
- ::dbtools::throwFeatureNotImplementedException( "XConnection::setTypeMap", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XConnection::setTypeMap", *this );
}
// XCloseable
diff --git a/connectivity/source/drivers/mozab/MPreparedStatement.cxx b/connectivity/source/drivers/mozab/MPreparedStatement.cxx
index e206c4a8b519..0de6749dfd78 100644
--- a/connectivity/source/drivers/mozab/MPreparedStatement.cxx
+++ b/connectivity/source/drivers/mozab/MPreparedStatement.cxx
@@ -184,7 +184,7 @@ sal_Bool SAL_CALL OPreparedStatement::execute( ) throw(SQLException, RuntimeExc
sal_Int32 SAL_CALL OPreparedStatement::executeUpdate( ) throw(SQLException, RuntimeException)
{
- ::dbtools::throwFeatureNotImplementedException( "XStatement::executeUpdate", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XStatement::executeUpdate", *this );
return 0;
}
@@ -222,56 +222,56 @@ Reference< XResultSet > SAL_CALL OPreparedStatement::executeQuery( ) throw(SQLE
void SAL_CALL OPreparedStatement::setBoolean( sal_Int32 /*parameterIndex*/, sal_Bool /*x*/ ) throw(SQLException, RuntimeException)
{
- ::dbtools::throwFeatureNotImplementedException( "XParameters::setBoolean", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XParameters::setBoolean", *this );
}
void SAL_CALL OPreparedStatement::setByte( sal_Int32 /*parameterIndex*/, sal_Int8 /*x*/ ) throw(SQLException, RuntimeException)
{
- ::dbtools::throwFeatureNotImplementedException( "XParameters::setByte", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XParameters::setByte", *this );
}
void SAL_CALL OPreparedStatement::setDate( sal_Int32 /*parameterIndex*/, const Date& /*aData*/ ) throw(SQLException, RuntimeException)
{
- ::dbtools::throwFeatureNotImplementedException( "XParameters::setDate", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XParameters::setDate", *this );
}
void SAL_CALL OPreparedStatement::setTime( sal_Int32 /*parameterIndex*/, const Time& /*aVal*/ ) throw(SQLException, RuntimeException)
{
- ::dbtools::throwFeatureNotImplementedException( "XParameters::setTime", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XParameters::setTime", *this );
}
void SAL_CALL OPreparedStatement::setTimestamp( sal_Int32 /*parameterIndex*/, const DateTime& /*aVal*/ ) throw(SQLException, RuntimeException)
{
- ::dbtools::throwFeatureNotImplementedException( "XParameters::setTimestamp", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XParameters::setTimestamp", *this );
}
void SAL_CALL OPreparedStatement::setDouble( sal_Int32 /*parameterIndex*/, double /*x*/ ) throw(SQLException, RuntimeException)
{
- ::dbtools::throwFeatureNotImplementedException( "XParameters::setDouble", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XParameters::setDouble", *this );
}
void SAL_CALL OPreparedStatement::setFloat( sal_Int32 /*parameterIndex*/, float /*x*/ ) throw(SQLException, RuntimeException)
{
- ::dbtools::throwFeatureNotImplementedException( "XParameters::setFloat", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XParameters::setFloat", *this );
}
void SAL_CALL OPreparedStatement::setInt( sal_Int32 /*parameterIndex*/, sal_Int32 /*x*/ ) throw(SQLException, RuntimeException)
{
- ::dbtools::throwFeatureNotImplementedException( "XParameters::setInt", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XParameters::setInt", *this );
}
void SAL_CALL OPreparedStatement::setLong( sal_Int32 /*parameterIndex*/, sal_Int64 /*aVal*/ ) throw(SQLException, RuntimeException)
{
- ::dbtools::throwFeatureNotImplementedException( "XParameters::setLong", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XParameters::setLong", *this );
}
@@ -288,31 +288,31 @@ void SAL_CALL OPreparedStatement::setNull( sal_Int32 parameterIndex, sal_Int32 /
void SAL_CALL OPreparedStatement::setClob( sal_Int32 /*parameterIndex*/, const Reference< XClob >& /*x*/ ) throw(SQLException, RuntimeException)
{
- ::dbtools::throwFeatureNotImplementedException( "XParameters::setClob", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XParameters::setClob", *this );
}
void SAL_CALL OPreparedStatement::setBlob( sal_Int32 /*parameterIndex*/, const Reference< XBlob >& /*x*/ ) throw(SQLException, RuntimeException)
{
- ::dbtools::throwFeatureNotImplementedException( "XParameters::setBlob", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XParameters::setBlob", *this );
}
void SAL_CALL OPreparedStatement::setArray( sal_Int32 /*parameterIndex*/, const Reference< XArray >& /*x*/ ) throw(SQLException, RuntimeException)
{
- ::dbtools::throwFeatureNotImplementedException( "XParameters::setArray", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XParameters::setArray", *this );
}
void SAL_CALL OPreparedStatement::setRef( sal_Int32 /*parameterIndex*/, const Reference< XRef >& /*x*/ ) throw(SQLException, RuntimeException)
{
- ::dbtools::throwFeatureNotImplementedException( "XParameters::setRef", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XParameters::setRef", *this );
}
void SAL_CALL OPreparedStatement::setObjectWithInfo( sal_Int32 /*parameterIndex*/, const Any& /*x*/, sal_Int32 /*sqlType*/, sal_Int32 /*scale*/ ) throw(SQLException, RuntimeException)
{
- ::dbtools::throwFeatureNotImplementedException( "XParameters::setObjectWithInfo", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XParameters::setObjectWithInfo", *this );
}
@@ -330,26 +330,26 @@ void SAL_CALL OPreparedStatement::setObject( sal_Int32 parameterIndex, const Any
void SAL_CALL OPreparedStatement::setShort( sal_Int32 /*parameterIndex*/, sal_Int16 /*x*/ ) throw(SQLException, RuntimeException)
{
- ::dbtools::throwFeatureNotImplementedException( "XParameters::setShort", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XParameters::setShort", *this );
}
void SAL_CALL OPreparedStatement::setBytes( sal_Int32 /*parameterIndex*/, const Sequence< sal_Int8 >& /*x*/ ) throw(SQLException, RuntimeException)
{
- ::dbtools::throwFeatureNotImplementedException( "XParameters::setBytes", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XParameters::setBytes", *this );
}
void SAL_CALL OPreparedStatement::setCharacterStream( sal_Int32 /*parameterIndex*/, const Reference< ::com::sun::star::io::XInputStream >& /*x*/, sal_Int32 /*length*/ ) throw(SQLException, RuntimeException)
{
- ::dbtools::throwFeatureNotImplementedException( "XParameters::setCharacterStream", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XParameters::setCharacterStream", *this );
}
void SAL_CALL OPreparedStatement::setBinaryStream( sal_Int32 /*parameterIndex*/, const Reference< ::com::sun::star::io::XInputStream >& /*x*/, sal_Int32 /*length*/ ) throw(SQLException, RuntimeException)
{
- ::dbtools::throwFeatureNotImplementedException( "XParameters::setBinaryStream", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XParameters::setBinaryStream", *this );
}
diff --git a/connectivity/source/drivers/mozab/MResultSet.cxx b/connectivity/source/drivers/mozab/MResultSet.cxx
index 519a1b1d69e3..11c6a4bf34f6 100644
--- a/connectivity/source/drivers/mozab/MResultSet.cxx
+++ b/connectivity/source/drivers/mozab/MResultSet.cxx
@@ -1725,7 +1725,7 @@ void SAL_CALL OResultSet::updateInt( sal_Int32 columnIndex, sal_Int32 x ) throw(
void SAL_CALL OResultSet::updateLong( sal_Int32 /*columnIndex*/, sal_Int64 /*x*/ ) throw(SQLException, RuntimeException)
{
- ::dbtools::throwFeatureNotImplementedException( "XRowUpdate::updateLong", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XRowUpdate::updateLong", *this );
}
void SAL_CALL OResultSet::updateFloat( sal_Int32 columnIndex, float x ) throw(SQLException, RuntimeException)
@@ -1956,7 +1956,7 @@ void OResultSet::setOrderByAscending(const ::std::vector<TAscendingOrder>& _aOrd
}
Sequence< sal_Int32 > SAL_CALL OResultSet::deleteRows( const Sequence< Any >& /*rows*/ ) throw(SQLException, RuntimeException)
{
- ::dbtools::throwFeatureNotImplementedException( "XDeleteRows::deleteRows", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XDeleteRows::deleteRows", *this );
return Sequence< sal_Int32 >();
};
diff --git a/connectivity/source/drivers/mozab/MStatement.cxx b/connectivity/source/drivers/mozab/MStatement.cxx
index 3e738fa13119..842db6b9ec49 100644
--- a/connectivity/source/drivers/mozab/MStatement.cxx
+++ b/connectivity/source/drivers/mozab/MStatement.cxx
@@ -353,7 +353,7 @@ Any SAL_CALL OStatement::queryInterface( const Type & rType ) throw(RuntimeExcep
sal_Int32 SAL_CALL OCommonStatement::executeUpdate( const OUString& /*sql*/ ) throw(SQLException, RuntimeException)
{
- ::dbtools::throwFeatureNotImplementedException( "XStatement::executeUpdate", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XStatement::executeUpdate", *this );
return 0;
}
diff --git a/connectivity/source/drivers/odbc/OConnection.cxx b/connectivity/source/drivers/odbc/OConnection.cxx
index 93c0b3ee83b1..5a0761d81d37 100644
--- a/connectivity/source/drivers/odbc/OConnection.cxx
+++ b/connectivity/source/drivers/odbc/OConnection.cxx
@@ -304,7 +304,7 @@ Reference< XPreparedStatement > SAL_CALL OConnection::prepareStatement( const OU
Reference< XPreparedStatement > SAL_CALL OConnection::prepareCall( const OUString& /*sql*/ ) throw(SQLException, RuntimeException, std::exception)
{
- ::dbtools::throwFeatureNotImplementedException( "XConnection::prepareCall", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XConnection::prepareCall", *this );
return NULL;
}
@@ -464,7 +464,7 @@ Reference< ::com::sun::star::container::XNameAccess > SAL_CALL OConnection::getT
void SAL_CALL OConnection::setTypeMap( const Reference< ::com::sun::star::container::XNameAccess >& /*typeMap*/ ) throw(SQLException, RuntimeException, std::exception)
{
- ::dbtools::throwFeatureNotImplementedException( "XConnection::setTypeMap", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XConnection::setTypeMap", *this );
}
// XCloseable
diff --git a/connectivity/source/sdbcx/VGroup.cxx b/connectivity/source/sdbcx/VGroup.cxx
index 960c320d068d..c71f22e50fc8 100644
--- a/connectivity/source/sdbcx/VGroup.cxx
+++ b/connectivity/source/sdbcx/VGroup.cxx
@@ -133,14 +133,14 @@ void SAL_CALL OGroup::grantPrivileges( const OUString& /*objName*/, sal_Int32 /*
{
::osl::MutexGuard aGuard(m_aMutex);
checkDisposed(OGroup_BASE::rBHelper.bDisposed);
- throwFeatureNotImplementedException( "XAuthorizable::grantPrivileges", *this );
+ throwFeatureNotImplementedSQLException( "XAuthorizable::grantPrivileges", *this );
}
void SAL_CALL OGroup::revokePrivileges( const OUString& /*objName*/, sal_Int32 /*objType*/, sal_Int32 /*objPrivileges*/ ) throw(::com::sun::star::sdbc::SQLException, RuntimeException, std::exception)
{
::osl::MutexGuard aGuard(m_aMutex);
checkDisposed(OGroup_BASE::rBHelper.bDisposed);
- throwFeatureNotImplementedException( "XAuthorizable::revokePrivileges", *this );
+ throwFeatureNotImplementedSQLException( "XAuthorizable::revokePrivileges", *this );
}
::com::sun::star::uno::Reference< ::com::sun::star::beans::XPropertySetInfo > SAL_CALL OGroup::getPropertySetInfo( ) throw(::com::sun::star::uno::RuntimeException, std::exception)
@@ -155,7 +155,7 @@ OUString SAL_CALL OGroup::getName( ) throw(::com::sun::star::uno::RuntimeExcept
void SAL_CALL OGroup::setName( const OUString& /*aName*/ ) throw(::com::sun::star::uno::RuntimeException, std::exception)
{
- throwFeatureNotImplementedException( "XNamed::setName", *this );
+ throwFeatureNotImplementedRuntimeException( "XNamed::setName", *this );
}
// XInterface
diff --git a/connectivity/source/sdbcx/VTable.cxx b/connectivity/source/sdbcx/VTable.cxx
index 18d7c35bab7f..23cfca9e3baf 100644
--- a/connectivity/source/sdbcx/VTable.cxx
+++ b/connectivity/source/sdbcx/VTable.cxx
@@ -281,12 +281,12 @@ Reference< XDatabaseMetaData> OTable::getMetaData() const
// XAlterTable
void SAL_CALL OTable::alterColumnByName( const OUString& /*colName*/, const Reference< XPropertySet >& /*descriptor*/ ) throw(SQLException, NoSuchElementException, RuntimeException, std::exception)
{
- throwFeatureNotImplementedException( "XAlterTable::alterColumnByName", *this );
+ throwFeatureNotImplementedSQLException( "XAlterTable::alterColumnByName", *this );
}
void SAL_CALL OTable::alterColumnByIndex( sal_Int32 /*index*/, const Reference< XPropertySet >& /*descriptor*/ ) throw(SQLException, ::com::sun::star::lang::IndexOutOfBoundsException, RuntimeException, std::exception)
{
- throwFeatureNotImplementedException( "XAlterTable::alterColumnByIndex", *this );
+ throwFeatureNotImplementedSQLException( "XAlterTable::alterColumnByIndex", *this );
}
::com::sun::star::uno::Reference< ::com::sun::star::beans::XPropertySetInfo > SAL_CALL OTable::getPropertySetInfo( ) throw(::com::sun::star::uno::RuntimeException, std::exception)
diff --git a/connectivity/source/sdbcx/VUser.cxx b/connectivity/source/sdbcx/VUser.cxx
index 911c8d9cbbab..393493b67dae 100644
--- a/connectivity/source/sdbcx/VUser.cxx
+++ b/connectivity/source/sdbcx/VUser.cxx
@@ -94,7 +94,7 @@ void SAL_CALL OUser::changePassword( const OUString& /*objPassword*/, const OUSt
{
::osl::MutexGuard aGuard(m_aMutex);
checkDisposed(OUser_BASE::rBHelper.bDisposed);
- ::dbtools::throwFeatureNotImplementedException( "XUser::changePassword", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XUser::changePassword", *this );
}
// XGroupsSupplier
@@ -128,7 +128,7 @@ sal_Int32 SAL_CALL OUser::getPrivileges( const OUString& /*objName*/, sal_Int32
{
::osl::MutexGuard aGuard(m_aMutex);
checkDisposed(OUser_BASE::rBHelper.bDisposed);
- ::dbtools::throwFeatureNotImplementedException( "XAuthorizable::changePassword", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XAuthorizable::changePassword", *this );
return 0;
}
@@ -136,7 +136,7 @@ sal_Int32 SAL_CALL OUser::getGrantablePrivileges( const OUString& /*objName*/, s
{
::osl::MutexGuard aGuard(m_aMutex);
checkDisposed(OUser_BASE::rBHelper.bDisposed);
- ::dbtools::throwFeatureNotImplementedException( "XAuthorizable::getGrantablePrivileges", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XAuthorizable::getGrantablePrivileges", *this );
return 0;
}
@@ -147,14 +147,14 @@ void SAL_CALL OUser::grantPrivileges( const OUString& /*objName*/, sal_Int32 /*o
{
::osl::MutexGuard aGuard(m_aMutex);
checkDisposed(OUser_BASE::rBHelper.bDisposed);
- ::dbtools::throwFeatureNotImplementedException( "XAuthorizable::grantPrivileges", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XAuthorizable::grantPrivileges", *this );
}
void SAL_CALL OUser::revokePrivileges( const OUString& /*objName*/, sal_Int32 /*objType*/, sal_Int32 /*objPrivileges*/ ) throw(::com::sun::star::sdbc::SQLException, ::com::sun::star::uno::RuntimeException, std::exception)
{
::osl::MutexGuard aGuard(m_aMutex);
checkDisposed(OUser_BASE::rBHelper.bDisposed);
- ::dbtools::throwFeatureNotImplementedException( "XAuthorizable::revokePrivileges", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XAuthorizable::revokePrivileges", *this );
}
::com::sun::star::uno::Reference< ::com::sun::star::beans::XPropertySetInfo > SAL_CALL OUser::getPropertySetInfo( ) throw(::com::sun::star::uno::RuntimeException, std::exception)
diff --git a/dbaccess/source/core/api/RowSet.cxx b/dbaccess/source/core/api/RowSet.cxx
index 534093a20d6a..e31879e48b55 100644
--- a/dbaccess/source/core/api/RowSet.cxx
+++ b/dbaccess/source/core/api/RowSet.cxx
@@ -2629,22 +2629,22 @@ void SAL_CALL ORowSet::setObjectWithInfo( sal_Int32 parameterIndex, const Any& x
void SAL_CALL ORowSet::setRef( sal_Int32 /*parameterIndex*/, const Reference< XRef >& /*x*/ ) throw(SQLException, RuntimeException, std::exception)
{
- ::dbtools::throwFeatureNotImplementedException( "XParameters::setRef", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XParameters::setRef", *this );
}
void SAL_CALL ORowSet::setBlob( sal_Int32 /*parameterIndex*/, const Reference< XBlob >& /*x*/ ) throw(SQLException, RuntimeException, std::exception)
{
- ::dbtools::throwFeatureNotImplementedException( "XParameters::setBlob", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XParameters::setBlob", *this );
}
void SAL_CALL ORowSet::setClob( sal_Int32 /*parameterIndex*/, const Reference< XClob >& /*x*/ ) throw(SQLException, RuntimeException, std::exception)
{
- ::dbtools::throwFeatureNotImplementedException( "XParameters::setClob", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XParameters::setClob", *this );
}
void SAL_CALL ORowSet::setArray( sal_Int32 /*parameterIndex*/, const Reference< XArray >& /*x*/ ) throw(SQLException, RuntimeException, std::exception)
{
- ::dbtools::throwFeatureNotImplementedException( "XParameters::setArray", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XParameters::setArray", *this );
}
void SAL_CALL ORowSet::clearParameters( ) throw(SQLException, RuntimeException, std::exception)
diff --git a/dbaccess/source/core/api/RowSetBase.cxx b/dbaccess/source/core/api/RowSetBase.cxx
index 0bcee0cfdbfc..09c6b1ad8f2b 100644
--- a/dbaccess/source/core/api/RowSetBase.cxx
+++ b/dbaccess/source/core/api/RowSetBase.cxx
@@ -378,7 +378,7 @@ Any SAL_CALL ORowSetBase::getObject( sal_Int32 columnIndex, const Reference< XNa
Reference< XRef > SAL_CALL ORowSetBase::getRef( sal_Int32 /*columnIndex*/ ) throw(SQLException, RuntimeException, std::exception)
{
- ::dbtools::throwFeatureNotImplementedException( "XRow::getRef", *m_pMySelf );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XRow::getRef", *m_pMySelf );
return NULL;
}
@@ -394,7 +394,7 @@ Reference< XClob > SAL_CALL ORowSetBase::getClob( sal_Int32 columnIndex ) throw(
Reference< XArray > SAL_CALL ORowSetBase::getArray( sal_Int32 /*columnIndex*/ ) throw(SQLException, RuntimeException, std::exception)
{
- ::dbtools::throwFeatureNotImplementedException( "XRow::getArray", *m_pMySelf );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XRow::getArray", *m_pMySelf );
return NULL;
}
diff --git a/include/connectivity/dbexception.hxx b/include/connectivity/dbexception.hxx
index 1e7fade75af1..c93371618344 100644
--- a/include/connectivity/dbexception.hxx
+++ b/include/connectivity/dbexception.hxx
@@ -285,13 +285,27 @@ OOO_DLLPUBLIC_DBTOOLS void throwGenericSQLException(
@param _pNextException
the next exception to chain into the thrown exception, if any
*/
-OOO_DLLPUBLIC_DBTOOLS void throwFeatureNotImplementedException(
+OOO_DLLPUBLIC_DBTOOLS void throwFeatureNotImplementedSQLException(
const OUString& _rFeatureName,
const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XInterface >& _rxContext,
const ::com::sun::star::uno::Any* _pNextException = NULL
)
- throw (::com::sun::star::sdbc::SQLException);
+ throw (css::sdbc::SQLException);
+/** throw a RuntimeException (Optional feature not implemented)
+ @param _rFeatureName
+ a description of the feature which is not implemented. It's recommended that the feature
+ name is built from the name of the interface plus its method, for instance "XParameters::updateBinaryStream"
+ @param _rxContext
+ the context of the exception
+ @param _pNextException
+ the next exception to chain into the thrown exception, if any
+*/
+OOO_DLLPUBLIC_DBTOOLS void throwFeatureNotImplementedRuntimeException(
+ const OUString& _rFeatureName,
+ const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XInterface >& _rxContext
+ )
+ throw (css::uno::RuntimeException);
/** throw a SQLException with SQLState 42S22 (Column Not Found)
@param _rColumnNameName
diff --git a/connectivity/source/commontools/BlobHelper.cxx b/connectivity/source/commontools/BlobHelper.cxx
index 65a12ed43dd9..c4e83d759fea 100644
--- a/connectivity/source/commontools/BlobHelper.cxx
+++ b/connectivity/source/commontools/BlobHelper.cxx
@@ -47,7 +47,7 @@ BlobHelper::BlobHelper(const ::com::sun::star::uno::Sequence< sal_Int8 >& _val)
}
// The "return" after a call to throwFeatureNotImplementedException()
// (which always throws) will be detected as unreachable when doing
// global inlining.
@@ -55,13 +55,13 @@ SAL_WNOUNREACHABLE_CODE_PUSH
::sal_Int64 SAL_CALL BlobHelper::position( const ::com::sun::star::uno::Sequence< ::sal_Int8 >& /*pattern*/, ::sal_Int64 /*start*/ ) throw (::com::sun::star::sdbc::SQLException, ::com::sun::star::uno::RuntimeException, std::exception)
{
- ::dbtools::throwFeatureNotImplementedException( "XBlob::position", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XBlob::position", *this );
return 0;
}
::sal_Int64 SAL_CALL BlobHelper::positionOfBlob( const ::com::sun::star::uno::Reference< ::com::sun::star::sdbc::XBlob >& /*pattern*/, ::sal_Int64 /*start*/ ) throw (::com::sun::star::sdbc::SQLException, ::com::sun::star::uno::RuntimeException, std::exception)
{
- ::dbtools::throwFeatureNotImplementedException( "XBlob::positionOfBlob", *this );
+ ::dbtools::throwFeatureNotImplementedSQLException( "XBlob::positionOfBlob", *this );
return 0;
}
@@ -47,7 +47,7 @@ BlobHelper::BlobHelper(const ::com::sun::star::uno::Sequence< sal_Int8 >& _val)
}
-// The "return" after a call to throwFeatureNotImplementedException()
+// The "return" after a call to throwFeatureNotImplementedSQLException()
// (which always throws) will be detected as unreachable when doing
// global inlining.